@@ -156,6 +156,8 @@ class Session:
 			else:
 				raise ValueError("please specify a flavor")
 
+		self._flavor = flavor
+
 		if embeddings is None:
 			embeddings = []
 
@@ -167,7 +169,8 @@ class Session:
 			if embedding.is_contextual:
 				for doc in corpus:
 					if not doc.has_contextual_embedding(embedding.name):
-						raise RuntimeError(f"doc {doc.unique_id} misses contextual embedding {embedding.name}")
+						unique_id = corpus.get_unique_id(doc)
+						raise RuntimeError(f"doc {unique_id} misses contextual embedding {embedding.name}")
 
 		self._embedding_instances = collections.OrderedDict()
 		for embedding in self._embeddings:
@@ -179,7 +182,6 @@ class Session:
 
 		self._vocab = core.Vocabulary(self._embedding_manager)
 
-		self._flavor = flavor
 		self._collection = Collection(
 			self, self._vocab, corpus)
 
@@ -386,13 +388,13 @@ class LabSession(Session):
 		self._progress = None
 		self._last_progress_update = None
 
-	def interact(self, nlp):
+	def interact(self, nlp, **kwargs):
 		from vectorian.interact import InteractiveQuery
 
 		logger = logging.getLogger()
 		logger.setLevel(logging.WARNING)
 
-		q = InteractiveQuery(self, nlp)
+		q = InteractiveQuery(self, nlp, **kwargs)
 		return q.widget
 
 	def make_result(self, *args, **kwargs):
